def get_main_template():
    txt = """\
import argparse


def run(mode):
    if mode == 'your_mode':
        pass
    else:
        raise Exception('Unsupported Running Mode!')


if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    required = parser.add_argument_group('required arguments')
    required.add_argument(
        '-m', '--mode', help='Running Mode',
        choices=['your_mode']
    )
    opt = parser.parse_args()
    run(opt.mode)
    
    print('Job done. Good luck.')

"""
    return txt



def get_app_init():
    txt = """\
from rdkit import RDLogger
import sys
import os
import warnings

# close rdkit warning
lg = RDLogger.logger()
lg.setLevel(RDLogger.CRITICAL)

warnings.filterwarnings('ignore')
    """
    return txt



def get_readme_template(project_name):
    txt = '''\
# momo_PJ_name #
!!project description.

## Maintainer ##
!! your email address.

## Parameters ##
- `!!param`: !!type, default=!!default value. !!explanation

## Input & Output ##
Input:
- `!!file_name`  # !!comments

Output:
```
└── output
    ├── !!file_name_1  # !!comments
    └── !!file_name_2  # !!comments
```
'''
    return txt.replace('momo_PJ_name', project_name)
